@@ -280,7 +280,7 @@ sysinfo_logo_expose (GtkWidget *widget,
 
   cr = gdk_cairo_create(widget->window);
 
-  cairo_translate(cr, event->area.x, event->area.y);
+  cairo_translate(cr, widget->allocation.x, widget->allocation.y);
 
   cairo_move_to(cr, X_PAD + RADIUS, Y_PAD);
   cairo_line_to(cr, X_PAD + LOGO_W - RADIUS, Y_PAD);
@@ -397,7 +397,7 @@ procman_create_sysinfo_view(void)
 
   if (data->distro_release != "")
     {
-      // translators: Release 2.6.19
+      // xgettext: Release 2.6.19
       markup = g_strdup_printf(_("Release %s"), data->distro_release.c_str());
       distro_release_label = gtk_label_new(markup);
       gtk_misc_set_alignment(GTK_MISC(distro_release_label), 0.0, 0.5);
